==> haskell-mtl-prelude-2.0.3.2-2-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mtl-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 mtl-prelude
version:              2.0.3.2
visibility:           public
id:                   mtl-prelude-2.0.3.2-9BGR1BFr3kY3wIOhR3mm9O
key:                  mtl-prelude-2.0.3.2-9BGR1BFr3kY3wIOhR3mm9O
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/mtl-prelude 
synopsis:
    Reexports of most definitions from "mtl" and "transformers" 

description:
    This package only exports definitions from the \"mtl\" and \"transformers\"
    libraries.
    Unlike every module of \"mtl\" it does not reexport
    @Control.Monad@ and @Control.Monad.Fix@.

    In combination with the <http://hackage.haskell.org/package/base-prelude "base-prelude"> library,
    this should give you a quite rich prelude.

    The @2.*@ versions are restricted by
    the feature set of @mtl-2.2@ and @transformers-0.4@,
    however they provide support for newer versions of those libraries as well.

category:             Prelude
abi:                  a04aba244f9d58c43e5138728a39ebd6
exposed:              True
exposed-modules:      MTLPrelude
import-dirs:          /usr/lib/ghc-9.2.8/site-local/mtl-prelude-2.0.3.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/mtl-prelude-2.0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mtl-prelude
hs-libraries:         HSmtl-prelude-2.0.3.2-9BGR1BFr3kY3wIOhR3mm9O
depends:              base-4.16.4.0 mtl-2.2.2 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-mtl-prelude/html/mtl-prelude.haddock
haddock-html:         /usr/share/doc/haskell-mtl-prelude/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-mtl-prelude-2.0.3.2-3-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-mtl-prelude.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 mtl-prelude
version:              2.0.3.2
visibility:           public
id:                   mtl-prelude-2.0.3.2-7xslZDmOSoA5Ce4xlJ8R09
key:                  mtl-prelude-2.0.3.2-7xslZDmOSoA5Ce4xlJ8R09
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/mtl-prelude 
synopsis:
    Reexports of most definitions from "mtl" and "transformers" 

description:
    This package only exports definitions from the \"mtl\" and \"transformers\"
    libraries.
    Unlike every module of \"mtl\" it does not reexport
    @Control.Monad@ and @Control.Monad.Fix@.

    In combination with the <http://hackage.haskell.org/package/base-prelude "base-prelude"> library,
    this should give you a quite rich prelude.

    The @2.*@ versions are restricted by
    the feature set of @mtl-2.2@ and @transformers-0.4@,
    however they provide support for newer versions of those libraries as well.

category:             Prelude
abi:                  34a7393742fba97eead72f5e4cab1fd4
exposed:              True
exposed-modules:      MTLPrelude
import-dirs:          /usr/lib/ghc-9.4.8/site-local/mtl-prelude-2.0.3.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/mtl-prelude-2.0.3.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/mtl-prelude-2.0.3.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-mtl-prelude
hs-libraries:         HSmtl-prelude-2.0.3.2-7xslZDmOSoA5Ce4xlJ8R09
depends:              base-4.17.2.1 mtl-2.2.2 transformers-0.5.6.2
haddock-interfaces:   /usr/share/doc/haskell-mtl-prelude/html/mtl-prelude.haddock
haddock-html:         /usr/share/doc/haskell-mtl-prelude/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
